import type { Logger } from '@agentuity/core';
export interface CIBuildOptions {
    url?: string;
    directory?: string;
    trigger?: string;
    event?: string;
    message?: string;
    commit?: string;
    commitUrl?: string;
    branch?: string;
    repo?: string;
    provider?: string;
    pullRequestNumber?: number;
    pullRequestUrl?: string;
    logsUrl?: string;
    skipDnsValidation?: boolean;
    skipTypeCheck?: boolean;
}
export declare function hasProjectDependenciesInstalled(projectDir: string): Promise<boolean>;
export declare function sourceDownloadHeaders(url: string): Record<string, string> | undefined;
export declare function downloadSource(url: string, targetPath: string): Promise<void>;
export declare function buildDeployArgs(opts: CIBuildOptions): string[];
export declare function runCIBuild(opts: CIBuildOptions, _logger: Logger): Promise<void>;
//# sourceMappingURL=ci.d.ts.map